# ABSTRACT: WUPHF, a blast messaging system 
package WUPHF;
$WUPHF::VERSION = '0.001';
use Moo;

use strict;
use warnings;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

WUPHF - WUPHF, a blast messaging system 

=head1 VERSION

version 0.001

=head1 NAME 

WUPHF

=head1 DESCRIPTION 

WUPHF is a blast messaging system where users can link various services: Twitter, SMS, Facebook and receive notifications on all channels simultaneously

=head4 SEE ALSO/INSPIRATION

https://en.wikipedia.org/wiki/WUPHF.com

=head1 AUTHOR

Hunter McMillen <mcmillhj@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Hunter McMillen.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
